# flake8: noqa
"""Module implementing the clients for services."""
from npc_engine.service_clients.text_generation_client import TextGenerationClient
from npc_engine.service_clients.control_client import ControlClient
from npc_engine.service_clients.sequence_classifier_client import (
    SequenceClassifierClient,
)
from npc_engine.service_clients.similarity_client import SimilarityClient
